# cloudmersive-image-recognition-api-client

CloudmersiveImageRecognitionApiClient - the Ruby gem for the imageapi

Image Recognition and Processing APIs let you use Machine Learning to recognize and process images, and also perform useful image modification operations.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 2.0.5
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build cloudmersive-image-recognition-api-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./cloudmersive-image-recognition-api-client-2.0.5.gem
```
(for development, run `gem install --dev ./cloudmersive-image-recognition-api-client-2.0.5.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'cloudmersive-image-recognition-api-client', '~> 2.0.5'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'cloudmersive-image-recognition-api-client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'cloudmersive-image-recognition-api-client'

# Setup authorization
CloudmersiveImageRecognitionApiClient.configure do |config|
  # Configure API key authorization: Apikey
  config.api_key['Apikey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Apikey'] = 'Bearer'
end

api_instance = CloudmersiveImageRecognitionApiClient::ArtisticApi.new

style = 'style_example' # String | The style of the painting to apply.  To start, try \"udnie\" a painting style.  Possible values are: \"udnie\", \"wave\", \"la_muse\", \"rain_princess\".

image_file = File.new('/path/to/file.txt') # File | Image file to perform the operation on.  Common file formats such as PNG, JPEG are supported.


begin
  #Transform an image into an artistic painting automatically
  result = api_instance.artistic_painting(style, image_file)
  p result
rescue CloudmersiveImageRecognitionApiClient::ApiError => e
  puts "Exception when calling ArtisticApi->artistic_painting: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.cloudmersive.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CloudmersiveImageRecognitionApiClient::ArtisticApi* | [**artistic_painting**](docs/ArtisticApi.md#artistic_painting) | **POST** /image/artistic/painting/{style} | Transform an image into an artistic painting automatically
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_bmp**](docs/ConvertApi.md#convert_to_bmp) | **POST** /image/convert/to/bmp | Convert input image to Bitmap BMP format
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_gif**](docs/ConvertApi.md#convert_to_gif) | **POST** /image/convert/to/gif | Convert input image to GIF format
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_jpg**](docs/ConvertApi.md#convert_to_jpg) | **POST** /image/convert/to/jpg/{quality} | Convert input image to JPG, JPEG format
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_photoshop**](docs/ConvertApi.md#convert_to_photoshop) | **POST** /image/convert/to/psd | Convert input image to Photoshop PSD format
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_png**](docs/ConvertApi.md#convert_to_png) | **POST** /image/convert/to/png | Convert input image to PNG format
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_tiff**](docs/ConvertApi.md#convert_to_tiff) | **POST** /image/convert/to/tiff | Convert input image to TIFF format
*CloudmersiveImageRecognitionApiClient::ConvertApi* | [**convert_to_web_p**](docs/ConvertApi.md#convert_to_web_p) | **POST** /image/convert/to/webp | Convert input image to WebP format
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_auto_orient**](docs/EditApi.md#edit_auto_orient) | **POST** /image/edit/auto-orient/remove-exif | Normalizes image rotation and removes EXIF rotation data
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_composite_basic**](docs/EditApi.md#edit_composite_basic) | **POST** /image/edit/composite/{location} | Composite two images together
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_composite_precise**](docs/EditApi.md#edit_composite_precise) | **POST** /image/edit/composite/precise | Composite two images together precisely
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_contrast_adaptive**](docs/EditApi.md#edit_contrast_adaptive) | **POST** /image/edit/contrast/{gamma}/adaptive | Adaptively adjust the contrast of the image to be more appealing and easy to see
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_crop_circle**](docs/EditApi.md#edit_crop_circle) | **POST** /image/edit/crop/circle/{left}/{top}/{radius} | Crop an image to an circular area
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_crop_rectangle**](docs/EditApi.md#edit_crop_rectangle) | **POST** /image/edit/crop/rectangle/{left}/{top}/{width}/{height} | Crop an image to a rectangular area
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_draw_polygon**](docs/EditApi.md#edit_draw_polygon) | **POST** /image/edit/draw/polygon | Draw a polygon onto an image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_draw_rectangle**](docs/EditApi.md#edit_draw_rectangle) | **POST** /image/edit/draw/rectangle | Draw a rectangle onto an image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_draw_text**](docs/EditApi.md#edit_draw_text) | **POST** /image/edit/draw/text | Draw text onto an image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_drop_shadow**](docs/EditApi.md#edit_drop_shadow) | **POST** /image/edit/drop-shadow/{X}/{Y}/{sigma}/{opacity} | Add a customizeable drop shadow to an image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_invert**](docs/EditApi.md#edit_invert) | **POST** /image/edit/invert | Invert, negate the colors in the image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_remove_exif_data**](docs/EditApi.md#edit_remove_exif_data) | **POST** /image/edit/remove-exif | Remove EXIF data from the image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_remove_transparency**](docs/EditApi.md#edit_remove_transparency) | **POST** /image/edit/remove-transparency | Remove transparency from the image
*CloudmersiveImageRecognitionApiClient::EditApi* | [**edit_rotate**](docs/EditApi.md#edit_rotate) | **POST** /image/edit/rotate/{degrees}/angle | Rotate an image any number of degrees
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_compare**](docs/FaceApi.md#face_compare) | **POST** /image/face/compare-and-match | Compare and match faces
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_crop_first**](docs/FaceApi.md#face_crop_first) | **POST** /image/face/crop/first | Crop image to face with square crop
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_crop_first_round**](docs/FaceApi.md#face_crop_first_round) | **POST** /image/face/crop/first/round | Crop image to face with round crop
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_detect_age**](docs/FaceApi.md#face_detect_age) | **POST** /image/face/detect-age | Detect the age of people in an image
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_detect_gender**](docs/FaceApi.md#face_detect_gender) | **POST** /image/face/detect-gender | Detect the gender of people in an image
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_locate**](docs/FaceApi.md#face_locate) | **POST** /image/face/locate | Detect and find faces in an image
*CloudmersiveImageRecognitionApiClient::FaceApi* | [**face_locate_with_landmarks**](docs/FaceApi.md#face_locate_with_landmarks) | **POST** /image/face/locate-with-landmarks | Detect and find faces and landmarks eyes and nose and mouth in image
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_black_and_white**](docs/FilterApi.md#filter_black_and_white) | **POST** /image/filter/black-and-white | Convert image to black-and-white grayscale
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_despeckle**](docs/FilterApi.md#filter_despeckle) | **POST** /image/filter/despeckle | Despeckle to remove point noise from the image
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_edge_detect**](docs/FilterApi.md#filter_edge_detect) | **POST** /image/filter/edge-detect/{radius} | Detect and highlight edges in an image
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_emboss**](docs/FilterApi.md#filter_emboss) | **POST** /image/filter/emboss/{radius}/{sigma} | Emboss an image
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_gaussian_blur**](docs/FilterApi.md#filter_gaussian_blur) | **POST** /image/filter/blur/guassian/{radius}/{sigma} | Perform a guassian blur on the input image
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_motion_blur**](docs/FilterApi.md#filter_motion_blur) | **POST** /image/filter/blur/motion/{radius}/{sigma}/{angle} | Perform a motion blur on the input image
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_posterize**](docs/FilterApi.md#filter_posterize) | **POST** /image/filter/posterize | Posterize the image by reducing distinct colors
*CloudmersiveImageRecognitionApiClient::FilterApi* | [**filter_swirl**](docs/FilterApi.md#filter_swirl) | **POST** /image/filter/swirl | Swirl distort the image
*CloudmersiveImageRecognitionApiClient::InfoApi* | [**info_get_dominant_color**](docs/InfoApi.md#info_get_dominant_color) | **POST** /image/get-info/dominant-color | Returns the dominant colors of the image
*CloudmersiveImageRecognitionApiClient::InfoApi* | [**info_get_metadata**](docs/InfoApi.md#info_get_metadata) | **POST** /image/get-info/metadata | Returns the image metadata including EXIF and resolution
*CloudmersiveImageRecognitionApiClient::NsfwApi* | [**nsfw_classify**](docs/NsfwApi.md#nsfw_classify) | **POST** /image/nsfw/classify | Not safe for work NSFW racy content classification
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_describe**](docs/RecognizeApi.md#recognize_describe) | **POST** /image/recognize/describe | Describe an image in natural language
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_detect_and_unskew_document**](docs/RecognizeApi.md#recognize_detect_and_unskew_document) | **POST** /image/recognize/detect-document/unskew | Detect and unskew a photo of a document
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_detect_objects**](docs/RecognizeApi.md#recognize_detect_objects) | **POST** /image/recognize/detect-objects | Detect objects including types and locations in an image
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_detect_people**](docs/RecognizeApi.md#recognize_detect_people) | **POST** /image/recognize/detect-people | Detect people including locations in an image
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_detect_text_fine**](docs/RecognizeApi.md#recognize_detect_text_fine) | **POST** /image/recognize/detect-text/fine | Detect fine text in a photo of a document
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_detect_text_large**](docs/RecognizeApi.md#recognize_detect_text_large) | **POST** /image/recognize/detect-text/large | Detect large text in a photo
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_detect_vehicle_license_plates**](docs/RecognizeApi.md#recognize_detect_vehicle_license_plates) | **POST** /image/recognize/detect-vehicle-license-plates | Detect vehicle license plates in an image
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_find_symbol**](docs/RecognizeApi.md#recognize_find_symbol) | **POST** /image/recognize/find/symbol | Find the location of a symbol in an image
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_similarity_compare**](docs/RecognizeApi.md#recognize_similarity_compare) | **POST** /image/recognize/similarity/compare | Compare two images for similarity
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_similarity_hash**](docs/RecognizeApi.md#recognize_similarity_hash) | **POST** /image/recognize/similarity/hash | Generate a perceptual image hash
*CloudmersiveImageRecognitionApiClient::RecognizeApi* | [**recognize_similarity_hash_distance**](docs/RecognizeApi.md#recognize_similarity_hash_distance) | **POST** /image/recognize/similarity/hash/distance | Calculates the similarity between two perceptual image hashes
*CloudmersiveImageRecognitionApiClient::ResizeApi* | [**resize_post**](docs/ResizeApi.md#resize_post) | **POST** /image/resize/preserveAspectRatio/{maxWidth}/{maxHeight} | Resize an image while preserving aspect ratio
*CloudmersiveImageRecognitionApiClient::ResizeApi* | [**resize_resize_simple**](docs/ResizeApi.md#resize_resize_simple) | **POST** /image/resize/target/{width}/{height} | Resize an image
*CloudmersiveImageRecognitionApiClient::TextGenerationApi* | [**text_generation_create_handwriting_png**](docs/TextGenerationApi.md#text_generation_create_handwriting_png) | **POST** /image/text/create/handwriting/png | Create an image of handwriting in PNG format


## Documentation for Models

 - [CloudmersiveImageRecognitionApiClient::AgeDetectionResult](docs/AgeDetectionResult.md)
 - [CloudmersiveImageRecognitionApiClient::ColorResult](docs/ColorResult.md)
 - [CloudmersiveImageRecognitionApiClient::CreateHandwritingRequest](docs/CreateHandwritingRequest.md)
 - [CloudmersiveImageRecognitionApiClient::DetectedLicensePlate](docs/DetectedLicensePlate.md)
 - [CloudmersiveImageRecognitionApiClient::DetectedObject](docs/DetectedObject.md)
 - [CloudmersiveImageRecognitionApiClient::DominantColorResult](docs/DominantColorResult.md)
 - [CloudmersiveImageRecognitionApiClient::DrawPolygonInstance](docs/DrawPolygonInstance.md)
 - [CloudmersiveImageRecognitionApiClient::DrawPolygonRequest](docs/DrawPolygonRequest.md)
 - [CloudmersiveImageRecognitionApiClient::DrawRectangleInstance](docs/DrawRectangleInstance.md)
 - [CloudmersiveImageRecognitionApiClient::DrawRectangleRequest](docs/DrawRectangleRequest.md)
 - [CloudmersiveImageRecognitionApiClient::DrawTextInstance](docs/DrawTextInstance.md)
 - [CloudmersiveImageRecognitionApiClient::DrawTextRequest](docs/DrawTextRequest.md)
 - [CloudmersiveImageRecognitionApiClient::Face](docs/Face.md)
 - [CloudmersiveImageRecognitionApiClient::FaceCompareResponse](docs/FaceCompareResponse.md)
 - [CloudmersiveImageRecognitionApiClient::FaceLocateResponse](docs/FaceLocateResponse.md)
 - [CloudmersiveImageRecognitionApiClient::FaceLocateWithLandmarksResponse](docs/FaceLocateWithLandmarksResponse.md)
 - [CloudmersiveImageRecognitionApiClient::FaceMatch](docs/FaceMatch.md)
 - [CloudmersiveImageRecognitionApiClient::FacePoint](docs/FacePoint.md)
 - [CloudmersiveImageRecognitionApiClient::FaceWithLandmarks](docs/FaceWithLandmarks.md)
 - [CloudmersiveImageRecognitionApiClient::FindSymbolResult](docs/FindSymbolResult.md)
 - [CloudmersiveImageRecognitionApiClient::FineTextDetectionResult](docs/FineTextDetectionResult.md)
 - [CloudmersiveImageRecognitionApiClient::FineTextItem](docs/FineTextItem.md)
 - [CloudmersiveImageRecognitionApiClient::GenderDetectionResult](docs/GenderDetectionResult.md)
 - [CloudmersiveImageRecognitionApiClient::ImageDescriptionResponse](docs/ImageDescriptionResponse.md)
 - [CloudmersiveImageRecognitionApiClient::ImageMetadata](docs/ImageMetadata.md)
 - [CloudmersiveImageRecognitionApiClient::ImageMetadataExifValue](docs/ImageMetadataExifValue.md)
 - [CloudmersiveImageRecognitionApiClient::ImageSimilarityComparisonResponse](docs/ImageSimilarityComparisonResponse.md)
 - [CloudmersiveImageRecognitionApiClient::ImageSimilarityHashDistanceRequest](docs/ImageSimilarityHashDistanceRequest.md)
 - [CloudmersiveImageRecognitionApiClient::ImageSimilarityHashDistanceResponse](docs/ImageSimilarityHashDistanceResponse.md)
 - [CloudmersiveImageRecognitionApiClient::ImageSimilarityHashResponse](docs/ImageSimilarityHashResponse.md)
 - [CloudmersiveImageRecognitionApiClient::NsfwResult](docs/NsfwResult.md)
 - [CloudmersiveImageRecognitionApiClient::ObjectDetectionResult](docs/ObjectDetectionResult.md)
 - [CloudmersiveImageRecognitionApiClient::PersonWithAge](docs/PersonWithAge.md)
 - [CloudmersiveImageRecognitionApiClient::PersonWithGender](docs/PersonWithGender.md)
 - [CloudmersiveImageRecognitionApiClient::PolygonPoint](docs/PolygonPoint.md)
 - [CloudmersiveImageRecognitionApiClient::RecognitionOutcome](docs/RecognitionOutcome.md)
 - [CloudmersiveImageRecognitionApiClient::TextDetectionResult](docs/TextDetectionResult.md)
 - [CloudmersiveImageRecognitionApiClient::TextItem](docs/TextItem.md)
 - [CloudmersiveImageRecognitionApiClient::VehicleLicensePlateDetectionResult](docs/VehicleLicensePlateDetectionResult.md)


## Documentation for Authorization


### Apikey

- **Type**: API key
- **API key parameter name**: Apikey
- **Location**: HTTP header

